# covid19.py

Track the COVID-19 data in all the countries in the word from the command line. It is a [python](www.python.org) script inspired by [ahmadawais/corona-cli](https://github.com/ahmadawais/corona-cli) and it used the data from [NovelCOVID](https://github.com/NovelCOVID/API)

### Licence

DO WHAT THE FUCK YOU WANT TO PUBLIC LICENSE, version 2, December 2004.

<a href="http://www.wtfpl.net/"><img
       src="http://www.wtfpl.net/wp-content/uploads/2012/12/wtfpl-badge-1.png"
       width="88" height="31" alt="WTFPL" />
</a>
